==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/fi.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'fi', {
	button: {
		title: 'Painikkeen ominaisuudet',
		text: 'Teksti (arvo)',
		type: 'Tyyppi',
		typeBtn: 'Painike',
		typeSbm: 'Lähetä',
		typeRst: 'Tyhjennä'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Valintaruudun ominaisuudet',
		radioTitle: 'Radiopainikkeen ominaisuudet',
		value: 'Arvo',
		selected: 'Valittu'
	},
	form: {
		title: 'Lomakkeen ominaisuudet',
		menu: 'Lomakkeen ominaisuudet',
		action: 'Toiminto',
		method: 'Tapa',
		encoding: 'Enkoodaus'
	},
	hidden: {
		title: 'Piilokentän ominaisuudet',
		name: 'Nimi',
		value: 'Arvo'
	},
	select: {
		title: 'Valintakentän ominaisuudet',
		selectInfo: 'Info',
		opAvail: 'Ominaisuudet',
		value: 'Arvo',
		size: 'Koko',
		lines: 'Rivit',
		chkMulti: 'Salli usea valinta',
		opText: 'Teksti',
		opValue: 'Arvo',
		btnAdd: 'Lisää',
		btnModify: 'Muuta',
		btnUp: 'Ylös',
		btnDown: 'Alas',
		btnSetValue: 'Aseta valituksi',
		btnDelete: 'Poista'
	},
	textarea: {
		title: 'Tekstilaatikon ominaisuudet',
		cols: 'Sarakkeita',
		rows: 'Rivejä'
	},
	textfield: {
		title: 'Tekstikentän ominaisuudet',
		name: 'Nimi',
		value: 'Arvo',
		charWidth: 'Leveys',
		maxChars: 'Maksimi merkkimäärä',
		type: 'Tyyppi',
		typeText: 'Teksti',
		typePass: 'Salasana',
		typeEmail: 'Sähköposti',
		typeSearch: 'Haku',
		typeTel: 'Puhelinnumero',
		typeUrl: 'Osoite'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/fi.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'fi', {
	button: {
		title: 'Painikkeen ominaisuudet',
		text: 'Teksti (arvo)',
		type: 'Tyyppi',
		typeBtn: 'Painike',
		typeSbm: 'Lähetä',
		typeRst: 'Tyhjennä'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Valintaruudun ominaisuudet',
		radioTitle: 'Radiopainikkeen ominaisuudet',
		value: 'Arvo',
		selected: 'Valittu',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Lomakkeen ominaisuudet',
		menu: 'Lomakkeen ominaisuudet',
		action: 'Toiminto',
		method: 'Tapa',
		encoding: 'Enkoodaus'
	},
	hidden: {
		title: 'Piilokentän ominaisuudet',
		name: 'Nimi',
		value: 'Arvo'
	},
	select: {
		title: 'Valintakentän ominaisuudet',
		selectInfo: 'Info',
		opAvail: 'Ominaisuudet',
		value: 'Arvo',
		size: 'Koko',
		lines: 'Rivit',
		chkMulti: 'Salli usea valinta',
		required: 'Required', // MISSING
		opText: 'Teksti',
		opValue: 'Arvo',
		btnAdd: 'Lisää',
		btnModify: 'Muuta',
		btnUp: 'Ylös',
		btnDown: 'Alas',
		btnSetValue: 'Aseta valituksi',
		btnDelete: 'Poista'
	},
	textarea: {
		title: 'Tekstilaatikon ominaisuudet',
		cols: 'Sarakkeita',
		rows: 'Rivejä'
	},
	textfield: {
		title: 'Tekstikentän ominaisuudet',
		name: 'Nimi',
		value: 'Arvo',
		charWidth: 'Leveys',
		maxChars: 'Maksimi merkkimäärä',
		required: 'Required', // MISSING
		type: 'Tyyppi',
		typeText: 'Teksti',
		typePass: 'Salasana',
		typeEmail: 'Sähköposti',
		typeSearch: 'Haku',
		typeTel: 'Puhelinnumero',
		typeUrl: 'Osoite'
	}
} );
